@@ -1,13 +1,14 @@
+from django.utils.module_loading import import_string
 from django.utils.timezone import now
 
 from outputs import jobs
 
 
-def schedule_export(scheduler_id):
-    from outputs.models import Scheduler
-
+# TODO: review
+def schedule_export(scheduler_id, scheduler_class_name):
     # get scheduler by its identifier
-    scheduler = Scheduler.objects.get(pk=scheduler_id)
+    scheduler_class = import_string(scheduler_class_name)
+    scheduler = scheduler_class.objects.get(pk=scheduler_id)
 
     # delay export job in background
     jobs.execute_export.delay(scheduler.exporter_class, scheduler.exporter_params, language=scheduler.language)
