@@ -3,15 +3,14 @@ import io
 import json
 import operator
 
-import xlsxwriter
 from django.contrib import messages
 from django.contrib.contenttypes.models import ContentType
 from django.db.models import Count, QuerySet
 from django.http import HttpResponse
+from django.template import loader
 from django.utils import translation
 from django.utils.timezone import localtime
 from django.utils.translation import ugettext_lazy as _
-from xlsxwriter.utility import datetime_to_excel_datetime
 
 from pragmatic.templatetags.pragmatic_tags import filtered_values
 from outputs import jobs
@@ -222,6 +221,7 @@ class SelectExportMixin(ConfirmExportMixin, ExportFieldsPermissionsMixin):
 class FilterExporterMixin(object):
     filter_class = None
     queryset = None
+    model = None
 
     def __init__(self, params, **kwargs):
         self.params = params
@@ -231,6 +231,10 @@ class FilterExporterMixin(object):
         # create filter
         self.filter = self.get_filter()
 
+    @classmethod
+    def get_model(cls):
+        return cls.queryset.model if cls.queryset is not None else cls.model
+
     def get_filter(self):
         return self.filter_class(self.params, queryset=self.get_whole_queryset(self.params))
 
@@ -250,18 +254,10 @@ class FilterExporterMixin(object):
 
         return self.filter.qs
 
-    def get_message_body(self):
-        body = ''
-
-        filter_values = filtered_values(self.filter, self.params)
-
-        for field in filter_values.keys():
-            field_data = filter_values[field]
-            label = field_data['label']
-            value = field_data['value']
-            body = f'{body}{label}: {value}\n'
-
-        return body
+    def get_message_body(self, count):
+        template = loader.get_template('outputs/export_message_body.html')
+        fv = filtered_values(self.filter, self.params)
+        return template.render({'count': count, 'filtered_values': fv})
 
 
 class ExporterMixin(object):
@@ -269,9 +265,11 @@ class ExporterMixin(object):
     filename = None
     export_format = None
     export_context = None
+    send_separately = False
 
     def __init__(self, user, recipients, **kwargs):
         self.filename = kwargs.pop('filename', self.filename)
+        self.send_separately = kwargs.pop('send_separately', self.send_separately)
         self.user = user
         self.recipients = recipients
 
@@ -312,9 +310,12 @@ class ExporterMixin(object):
 
         return response
 
-    def get_message_body(self):
+    def get_message_body(self, count):
         raise NotImplementedError()
 
+    def get_message_subject(self):
+        return None
+
     def save_export(self):
         items = self.get_queryset().all()
 
@@ -351,6 +352,7 @@ class ExcelExporterMixin(ExporterMixin):
         'bold_money': {'num_format': '### ### ###.00 €', 'bold': True},
     }
     proxy_class = None
+    exclude_in_permission_widget = False
 
     @staticmethod
     def selectable_fields():
@@ -361,6 +363,7 @@ class ExcelExporterMixin(ExporterMixin):
         super().__init__(**kwargs)
 
         # create a workbook in memory
+        import xlsxwriter
         self.workbook = xlsxwriter.Workbook(self.output)
         self.workbook.remove_timezone = True
 
@@ -374,6 +377,7 @@ class ExcelExporterMixin(ExporterMixin):
 
     @staticmethod
     def to_excel_datetime(to_convert):
+        from xlsxwriter.utility import datetime_to_excel_datetime
         return datetime_to_excel_datetime(to_convert, False, False)
 
     def export(self):
@@ -547,7 +551,7 @@ class ExcelExporterMixin(ExporterMixin):
         objects = self.get_queryset()
 
         if not objects.exists():
-            raise ValueError()
+            return
 
         # use only selected fields
         fields, iterative_sets_fields = self.get_selected_fields(objects)
